@@ -166,6 +166,8 @@ int ipkg_prepare_url_for_install(ipkg_conf_t *conf, const char *url, char **name
 	  if (err)
 	       return err;
 	  pkg->local_filename = strdup(url);
+	  ipkg_message(conf, IPKG_DEBUG2, "Package %s provided by hand \(%s\).\n", pkg->name,pkg->local_filename);
+          pkg->provided_by_hand = 1;
 
      } else {
        return 0;
